emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[nongnu] externals/caml 07d301a 174/197: elisp: fixed grammar in docstri


From: Stefan Monnier
Subject: [nongnu] externals/caml 07d301a 174/197: elisp: fixed grammar in docstrings and comments
Date: Sat, 21 Nov 2020 01:20:01 -0500 (EST)

branch: externals/caml
commit 07d301adf265377df53906a00a3ca06d2c7446f2
Author: Max Mouratov <mmouratov@gmail.com>
Commit: Max Mouratov <mmouratov@gmail.com>

    elisp: fixed grammar in docstrings and comments
---
 caml-font-old.el |  2 +-
 caml-help.el     | 24 ++++++++++++------------
 caml-types.el    |  4 ++--
 caml.el          | 30 +++++++++++++++---------------
 camldebug.el     |  2 +-
 inf-caml.el      | 14 +++++++-------
 6 files changed, 38 insertions(+), 38 deletions(-)

diff --git a/caml-font-old.el b/caml-font-old.el
index 674beb6..fb39c22 100644
--- a/caml-font-old.el
+++ b/caml-font-old.el
@@ -42,7 +42,7 @@
     (setq font-lock-variable-name-face 'DarkGoldenRod)
     (setq font-lock-type-face 'DarkOliveGreen)
     (setq font-lock-reference-face 'CadetBlue)))
-  ; extra faces for documention
+  ; extra faces for documentation
   (make-face 'Stop)
   (set-face-foreground 'Stop "White")
   (set-face-background 'Stop "Red")
diff --git a/caml-types.el b/caml-types.el
index cc5d915..dc01af6 100644
--- a/caml-types.el
+++ b/caml-types.el
@@ -669,7 +669,7 @@ The function uses two overlays.
                            (error (message "End of buffer!")))))
                        (setq speed (* speed speed)))))
                   ;; main action, when the motion is inside the window
-                  ;; or on orginal button down event
+                  ;; or on original button down event
                   ((or (caml-mouse-movement-p event)
                        (equal original-event event))
                    (setq cnum (caml-event-point-end event))
@@ -732,7 +732,7 @@ The function uses two overlays.
       ;; However, it could also be a key stroke before mouse release.
       ;; Emacs does not allow to test whether mouse is up or down.
       ;; Not sure it is robust to loop for mouse release after an error
-      ;; occured, as is done for exploration.
+      ;; occurred, as is done for exploration.
       ;; So far, we just ignore next event. (Next line also be uncommenting.)
       (if event (caml-read-event)))))
 
diff --git a/caml.el b/caml.el
index def64b9..6b788b2 100644
--- a/caml.el
+++ b/caml.el
@@ -83,7 +83,7 @@ Priorities are assigned to `interesting' caml operators as 
follows:
 (make-variable-buffer-local 'caml-class-indent)
 
 (defvar caml-exception-indent 2
-  "*How many spaces to indent from a exception keyword in caml mode.")
+  "*How many spaces to indent from an exception keyword in caml mode.")
 (make-variable-buffer-local 'caml-exception-indent)
 
 (defvar caml-for-indent 2
@@ -99,7 +99,7 @@ Priorities are assigned to `interesting' caml operators as 
follows:
 (make-variable-buffer-local 'caml-function-indent)
 
 (defvar caml-if-indent  2
-  "*How many spaces to indent from a if keyword in caml mode.")
+  "*How many spaces to indent from an if keyword in caml mode.")
 (make-variable-buffer-local 'caml-if-indent)
 
 (defvar caml-if-else-indent 0
@@ -107,15 +107,15 @@ Priorities are assigned to `interesting' caml operators 
as follows:
 (make-variable-buffer-local 'caml-if-else-indent)
 
 (defvar caml-inherit-indent 2
-  "*How many spaces to indent from a inherit keyword in caml mode.")
+  "*How many spaces to indent from an inherit keyword in caml mode.")
 (make-variable-buffer-local 'caml-inherit-indent)
 
 (defvar caml-initializer-indent 2
-  "*How many spaces to indent from a initializer keyword in caml mode.")
+  "*How many spaces to indent from an initializer keyword in caml mode.")
 (make-variable-buffer-local 'caml-initializer-indent)
 
 (defvar caml-include-indent 2
-  "*How many spaces to indent from a include keyword in caml mode.")
+  "*How many spaces to indent from an include keyword in caml mode.")
 (make-variable-buffer-local 'caml-include-indent)
 
 (defvar caml-let-indent 2
@@ -139,11 +139,11 @@ Priorities are assigned to `interesting' caml operators 
as follows:
 (make-variable-buffer-local 'caml-module-indent)
 
 (defvar caml-object-indent 2
-  "*How many spaces to indent from a object keyword in caml mode.")
+  "*How many spaces to indent from an object keyword in caml mode.")
 (make-variable-buffer-local 'caml-object-indent)
 
 (defvar caml-of-indent 2
-  "*How many spaces to indent from a of keyword in caml mode.")
+  "*How many spaces to indent from an of keyword in caml mode.")
 (make-variable-buffer-local 'caml-of-indent)
 
 (defvar caml-parser-indent 4
@@ -261,7 +261,7 @@ Usually negative. nil is align on master.")
 (make-variable-buffer-local 'caml-|-extra-indent)
 
 (defvar caml-rb-extra-indent -2
-  "*Extra indent for caml lines statring with ].
+  "*Extra indent for caml lines starting with ].
 Usually negative. nil is align on master.")
 
 (defvar caml-rc-extra-indent -2
@@ -275,13 +275,13 @@ Usually negative. nil is align on master.")
 (defvar caml-electric-indent t
   "*Non-nil means electrically indent lines starting with |, ] or }.
 
-Many people find eletric keys irritating, so you can disable them if
+Many people find electric keys irritating, so you can disable them if
 you are one.")
 
 (defvar caml-electric-close-vector t
   "*Non-nil means electrically insert a | before a vector-closing ].
 
-Many people find eletric keys irritating, so you can disable them if
+Many people find electric keys irritating, so you can disable them if
 you are one. You should probably have this on, though, if you also
 have caml-electric-indent on, which see.")
 
@@ -623,8 +623,8 @@ have caml-electric-indent on, which see.")
 (defun caml-eval-phrase (arg &optional min max)
   "Send the phrase containing the point to the CAML process.
 With prefix-arg send as many phrases as its numeric value,
-If an error occurs during evalutaion, stop at this phrase and
-repport the error.
+If an error occurs during evaluation, stop at this phrase and
+report the error.
 
 Return nil if noerror and position of error if any.
 
@@ -1136,7 +1136,7 @@ to the end.
 
 (defun caml-in-comment-p ()
   "Returns non-nil if point is inside a caml comment.
-Returns nil for the parenthesis openning a comment."
+Returns nil for the parenthesis opening a comment."
   ;;we look for comments differently than literals. there are two
   ;;reasons for this. first, caml has nested comments and it is not so
   ;;clear that parse-partial-sexp supports them; second, if proper
@@ -1266,7 +1266,7 @@ Used to distinguish it from toplevel let construct.")
   "Look back for a caml keyword or operator matching KWOP-REGEXP.
 Second optional argument MIN-POS bounds the search.
 
-Ignore occurences inside literals. If found, return a list of two
+Ignore occurrences inside literals. If found, return a list of two
 values: the actual text of the keyword or operator, and a boolean
 indicating whether the keyword was one we looked for explicitly
 {non-nil}, or on the other hand one of the block-terminating
@@ -1971,7 +1971,7 @@ with prefix arg, indent that many phrases starting with 
the current phrase."
   "Explore type annotations by mouse dragging." t)
 
 (autoload 'caml-help "caml-help"
-  "Show documentation for qualilifed OCaml identifier." t)
+  "Show documentation for qualified OCaml identifier." t)
 (autoload 'caml-complete "caml-help"
   "Does completion for documented qualified OCaml identifier." t)
 (autoload 'ocaml-open-module "caml-help"
diff --git a/camldebug.el b/camldebug.el
index 674cd32..8b59942 100644
--- a/camldebug.el
+++ b/camldebug.el
@@ -99,7 +99,7 @@ The following commands are available:
 the last line referred to in the camldebug buffer.
 
 \\[camldebug-step], \\[camldebug-back] and \\[camldebug-next], in the camldebug
-window,call camldebug to step, backstep or next and then update the other 
window
+window, call camldebug to step, backstep or next and then update the other 
window
 with the current file and position.
 
 If you are in a source file, you may select a point to break
diff --git a/caml-help.el b/caml-help.el
index 6b1abc6..9e3a221 100644
--- a/caml-help.el
+++ b/caml-help.el
@@ -25,7 +25,7 @@
 ;;  This is a preliminary version.
 ;;
 ;;  Possible improvements?
-;;   - dump some databaes: Info, Lib, ...
+;;   - dump some databases: Info, Lib, ...
 ;;   - accept a search path for local libraries instead of current dir
 ;;     (then distinguish between different modules lying in different
 ;;     directories)
@@ -33,8 +33,8 @@
 ;;
 ;;  Abstract over
 ;;   - the viewing method and the database, so that the documentation for
 ;;     and identifier could be search in
 ;;       * info / html / man / mli's sources
 ;;       * viewed in Emacs or using an external previewer.
 ;;
 ;;  Take all identifiers (labels, Constructors, exceptions, etc.)
@@ -56,7 +56,7 @@
 (defvar ocaml-lib-path 'lazy
   "Path list for ocaml lib sources (mli files).
 
-`lazy' means ask ocaml to find it for your at first use.")
+`lazy' means ask ocaml to find it for you at first use.")
 (defun ocaml-lib-path ()
   "Compute if necessary and return the path for ocaml libs."
   (if (listp ocaml-lib-path) nil
@@ -233,7 +233,7 @@
   ocaml-visible-modules)
 
 (defun ocaml-open-module (arg)
-  "*Make module of name ARG visible whe ARG is a string.
+  "*Make module of name ARG visible when ARG is a string.
 When call interactively, make completion over known modules."
   (interactive "P")
   (if (not (stringp arg))
@@ -335,7 +335,7 @@ with an optional non-nil argument."
 (defun caml-complete (arg)
   "Does completion for OCaml identifiers qualified.
 
-It attemps to recognize an qualified identifier Module . entry
+It attemps to recognize a qualified identifier Module . entry
 around point using function \\[ocaml-qualified-identifier].
 
 If Module is defined, it does completion for identifier in Module.
@@ -647,14 +647,14 @@ current buffer using \\[ocaml-qualified-identifier]."
 (defun caml-help (arg)
   "Find documentation for OCaml qualified identifiers.
 
-It attemps to recognize an qualified identifier of the form
+It attempts to recognize a qualified identifier of the form
 ``Module . entry'' around point using function `ocaml-qualified-identifier'.
 
 If Module is undetermined it is temptatively guessed from the identifier name
-and according to visible modules.  If this is still unsucessful,  the user is
+and according to visible modules.  If this is still unsuccessful,  the user is
 then prompted for a Module name.
 
-The documentation for Module is first seach in the info manual if available,
+The documentation for Module is first searched in the info manual, if 
available,
 then in the ``module.mli'' source file.  The entry is then searched in the
 documentation.
 
@@ -666,7 +666,7 @@ Prefix arg 0 forces recompilation of visible modules (and 
their content)
 from the file content.
 
 Prefix arg 4 prompts for Module and identifier instead of guessing values
-from the possition of point in the current buffer."
+from the position of point in the current buffer."
   (interactive "p")
   (delete-overlay ocaml-help-ovl)
   (let ((module) (entry) (module-entry))
@@ -726,9 +726,9 @@ from the possition of point in the current buffer."
 (defvar ocaml-links nil
   "Local links in the current of last info node or interface file.
 
-The car of the list is a key that indentifies the module to prevent
+The car of the list is a key that identifies the module to prevent
 recompilation when next help command is relative to the same module.
-The cdr is a list of elments, each of which is an string and a pair of
+The cdr is a list of elements, each of which is a string and a pair of
 buffer positions."
 )
 (make-variable-buffer-local 'ocaml-links)
@@ -33,8 +33,8 @@
 ;;  Abstract over
 ;;   - the viewing method and the database, so that the documentation for
-;;     and identifier could be search in
-;;       * info / html / man / mli's sources
+;;     an identifier could be
+;;       * searched in info / html / man / mli's sources
 ;;       * viewed in Emacs or using an external previewer.
 ;;
diff --git a/inf-caml.el b/inf-caml.el
index 05bf318..3d2b2dc 100644
--- a/inf-caml.el
+++ b/inf-caml.el
@@ -23,7 +23,7 @@
 
 ;; User modifiable variables
 
-;; Whether you want the output buffer to be diplayed when you send a phrase
+;; Whether you want the output buffer to be displayed when you send a phrase
 
 (defvar caml-display-when-eval t
   "*If true, display the inferior caml buffer when evaluating expressions.")
@@ -205,7 +205,7 @@ Input and output via buffer `*inferior-caml*'."
     (goto-char loc)))
 
 
-;;; orgininal inf-caml.el ended here
+;;; original inf-caml.el ended here
 
 ;; as eval-phrase, but ignores errors.
 
@@ -225,16 +225,16 @@ should lies."
     beg))
 
 (defvar caml-previous-output nil
-  "tells the beginning of output in the shell-output buffer, so that the
-output can be retreived later, asynchronously.")
+  "Tells the beginning of output in the shell-output buffer, so that the
+output can be retrieved later, asynchronously.")
 
 ;; enriched version of eval-phrase, to repport errors.
 
 (defun inferior-caml-eval-phrase (arg &optional min max)
   "Send the phrase containing the point to the CAML process.
 With prefix-arg send as many phrases as its numeric value,
-If an error occurs during evalutaion, stop at this phrase and
-repport the error.
+If an error occurs during evaluation, stop at this phrase and
+report the error.
 
 Return nil if noerror and position of error if any.
 
@@ -225,16 +225,16 @@ should lies."
 
-;; enriched version of eval-phrase, to repport errors.
+;; enriched version of eval-phrase, to report errors.
 
 (defun inferior-caml-eval-phrase (arg &optional min max)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]